@@ -12,7 +12,6 @@ from logilab.common.date import nb_open_days
 
 from cubicweb.entities import AnyEntity, fetch_config
 from cubicweb.entities.adapters import IFTIndexableAdapter
-from cubicweb.interfaces import IPrevNext, ICalendarViews
 from cubicweb.selectors import is_instance
 
 from cubes.card.entities import Card as BaseCard
@@ -59,6 +58,7 @@ class Project(project.Project):
                      limit and ' LIMIT %s' % limit or '',
                      self.eid)
 
+
 class ProjectIFTIndexableAdapter(IFTIndexableAdapter):
     __select__ = is_instance('Project')
     entity_weight = 20.0
@@ -74,7 +74,8 @@ class Version(version.Version):
 
     def velocity(self):
         """return computed velocity or None if some information is missing"""
-        if self.finished():
+        iprogress = self.cw_adapt_to('IProgress')
+        if iprogress.finished():
             stop = self.stop_date()
         else:
             stop =  date.today()
@@ -83,7 +84,7 @@ class Version(version.Version):
             return None
         nb_days = nb_open_days(start, stop)
         if nb_days:
-            return self.progress_info()['done'] / float(nb_days)
+            return iprogress.progress_info()['done'] / float(nb_days)
         return None
 
     def tarball_name(self):
@@ -150,20 +151,20 @@ class VersionIMileStoneAdapter(version.VersionIMileStoneAdapter):
 
     def progress_info(self):
         """returns a dictionary describing load and progress of the version"""
-        version = self.entity
-        return {'estimated': version.progress_target,
-                'done': version.progress_done,
-                'todo': version.progress_todo,
-                'notestimated': len([ticket for ticket in version.reverse_done_in
-                                     if ticket.load is None]),
+        entity = self.entity
+        return {'estimated': entity.progress_target,
+                'done': entity.progress_done,
+                'todo': entity.progress_todo,
+                'notestimated': len([t for t in entity.reverse_done_in
+                                     if t.load is None]),
                 }
 
     def eta_date(self):
         """return expected date based on remaining tasks and velocity"""
-        version = self.entity
-        if version.cw_adapt_to('IWorkflowable').state != 'dev':
+        entity = self.entity
+        if entity.cw_adapt_to('IWorkflowable').state != 'dev':
             return None
-        velocity = version.velocity()
+        velocity = entity.velocity()
         if velocity is None:
             return None
         # XXX if velocity == 0, use a hidden attribute which is computed from
