@@ -6,7 +6,6 @@
 """
 __docformat__ = "restructuredtext en"
 
-from itertools import chain
 from datetime import datetime
 
 from cubicweb import ValidationError
@@ -60,7 +59,7 @@ class ChangeTicketStateOnVersionStatusChange(Hook):
 class AdjustPendingTicketState(Operation):
     def precommit_event(self):
         iwf = self.ticket.cw_adapt_to('IWorkflowable')
-        if (iwf.state in ('done', 'validation pending') and
+        if (iwf.state == 'validation pending' and
             (not self.ticket.done_in
              or self.ticket.done_in[0].cw_adapt_to('IWorkflowable').state != 'published')):
             msg = self.session._('moved away from published version')
@@ -76,7 +75,11 @@ class ChangeTicketStateOnDoneInChange(Hook):
     def __call__(self):
         ticket = self._cw.entity_from_eid(self.eidfrom)
         version = self._cw.entity_from_eid(self.eidto)
-        if ticket.cw_adapt_to('IWorkflowable').state in ('done', 'validation pending'):
+        # only change tickets in the validation pending state, not done
+        # (since we want this behaviour to occurs for tickets moved
+        # from a published version to an unpublished one, usually because
+        # of non-validation
+        if ticket.cw_adapt_to('IWorkflowable').state == 'validation pending':
             AdjustPendingTicketState(self._cw, ticket=ticket)
 
 
