@@ -2,7 +2,7 @@
 
 from datetime import datetime, timedelta
 
-from logilab.common.testlib import unittest_main, mock_object
+from logilab.common.testlib import unittest_main, SkipTest
 
 from cubicweb.devtools import ApptestConfiguration
 from cubicweb.devtools.testlib import AutoPopulateTest
@@ -15,7 +15,6 @@ from cubes.tracker.testutils import TrackerBaseTC
 from cubes.tracker.views import ticket, document
 from cubes.comment import views as commentactions
 from cubes.forge.views import project as myproject, boxes
-from cubes.testcard import views as tcviews
 from cubes.nosylist import views as nosylist
 
 ONEDAY = timedelta(1)
@@ -59,7 +58,7 @@ class ProjectTC(TrackerBaseTC):
         req = self.request()
         # manager user, in dev project
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('edit', actions.ModifyAction),
                                ('managepermission', actions.ManagePermissionsAction),
@@ -76,10 +75,10 @@ class ProjectTC(TrackerBaseTC):
                                ('addsubproject', myproject.ProjectAddSubProject),
                                ('pvrestexport', document.ProjectVersionExportAction),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
         wf = self.cubicweb.cw_adapt_to('IWorkflowable').current_workflow
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'temporarily stop development', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
                                 wf.transition_by_name('temporarily stop development').eid),
                                (u'stop maintainance', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
@@ -93,7 +92,7 @@ class ProjectTC(TrackerBaseTC):
         self.login('logilabien')
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('edit', actions.ModifyAction),
                                ('addrelated', actions.AddRelatedActions),
@@ -107,9 +106,9 @@ class ProjectTC(TrackerBaseTC):
                                ('addsubproject', myproject.ProjectAddSubProject),
                                ('pvrestexport', document.ProjectVersionExportAction),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'temporarily stop development', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
                                 wf.transition_by_name('temporarily stop development').eid),
                                (u'stop maintainance', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
@@ -122,14 +121,14 @@ class ProjectTC(TrackerBaseTC):
         self.login('anon')
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('addrelated', actions.AddRelatedActions),
                                ('pvrestexport', document.ProjectVersionExportAction),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [])
         # std user, in dev project
         self.restore_connection()
@@ -137,14 +136,14 @@ class ProjectTC(TrackerBaseTC):
         self.login('toto')
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('addrelated', actions.AddRelatedActions),
                                ('pvrestexport', document.ProjectVersionExportAction),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [])
         # std user with perm, in dev project
         self.restore_connection()# use the admin connection to create and link a permission
@@ -154,7 +153,7 @@ class ProjectTC(TrackerBaseTC):
         self.login('toto')
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('edit', actions.ModifyAction),
                                ('addrelated', actions.AddRelatedActions),
@@ -165,9 +164,9 @@ class ProjectTC(TrackerBaseTC):
                                ('addtestcard', myproject.ProjectAddTestCard),
                                ('pvrestexport', document.ProjectVersionExportAction),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [])
         # std user with client perm, in dev project
         self.restore_connection()# use the admin connection to create and link a permission
@@ -178,7 +177,7 @@ class ProjectTC(TrackerBaseTC):
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('edit', actions.ModifyAction),
                                ('addrelated', actions.AddRelatedActions),
@@ -190,9 +189,9 @@ class ProjectTC(TrackerBaseTC):
                                ('addtestcard', myproject.ProjectAddTestCard),
                                ('pvrestexport', document.ProjectVersionExportAction),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [])
         # manager user, moved project
         self.restore_connection()
@@ -200,7 +199,7 @@ class ProjectTC(TrackerBaseTC):
         self.commit()
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('edit', actions.ModifyAction),
                                ('managepermission', actions.ManagePermissionsAction),
@@ -210,9 +209,9 @@ class ProjectTC(TrackerBaseTC):
                                ('actionsbox_notifications_mgmt', nosylist.INosyListManageNotificationsAction),
                                ('pvrestexport', document.ProjectVersionExportAction),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'view history', u'http://testing.fr/cubicweb/project/cubicweb?vid=wfhistory')])
 
     def test_doap(self):
@@ -223,7 +222,7 @@ class ProjectTC(TrackerBaseTC):
         self.cubicweb.view('doap')
 
     def test_creator_interested_in(self):
-        self.assertEquals(len(self.cubicweb.reverse_interested_in), 1)
+        self.assertEqual(len(self.cubicweb.reverse_interested_in), 1)
 
 
 class VersionTC(TrackerBaseTC):
@@ -265,34 +264,34 @@ class TicketTC(TrackerBaseTC):
 
     def test_creator_interested_in(self):
         t = self.create_ticket('pouet').get_entity(0, 0)
-        self.assertEquals(len(t.reverse_interested_in), 1)
+        self.assertEqual(len(t.reverse_interested_in), 1)
 
     def test_load_after_state_changed_deprecated(self):
         self.t1.set_attributes(load=2)
         self.t1.cw_adapt_to('IWorkflowable').change_state('deprecated')
         self.commit()
         self.t1.pop('load', None)
-        self.assertEquals(self.t1.load, 0)
+        self.assertEqual(self.t1.load, 0)
 
     def test_load_after_state_changed_rejected(self):
         self.t1.set_attributes(load=2)
         self.t1.cw_adapt_to('IWorkflowable').change_state('rejected')
         self.commit()
         self.t1.pop('load', None)
-        self.assertEquals(self.t1.load, 0)
+        self.assertEqual(self.t1.load, 0)
 
     def test_auto_set_load_left_1(self):
         t = self.execute('INSERT Ticket X: X title "story1", X concerns P, X load 1 '
                          'WHERE P is Project').get_entity(0, 0)
-        self.assertEquals(t.load_left, 1.0)
+        self.assertEqual(t.load_left, 1.0)
 
     def test_auto_set_load_left_2(self):
         self.execute('SET X load 1 WHERE X eid %(x)s', {'x': self.t1.eid})
         self.t1.pop('load_left', None)
-        self.assertEquals(self.t1.load_left, 1)
+        self.assertEqual(self.t1.load_left, 1)
         self.execute('SET X load 2 WHERE X eid %(x)s', {'x': self.t1.eid})
         self.t1.pop('load_left', None)
-        self.assertEquals(self.t1.load_left, 1)
+        self.assertEqual(self.t1.load_left, 1)
 
     def test_modification_date_after_comment_added(self):
         olddate = datetime.today() - ONEDAY
@@ -327,7 +326,7 @@ class TicketTC(TrackerBaseTC):
                               ('actionsbox_notifications_mgmt', nosylist.INosyListManageNotificationsAction),
                               ('movetonext', ticket.TicketMoveToNextVersionActions),
                               ('reply_comment', commentactions.AddCommentAction)])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [('add Ticket attachment File subject',
                                 'http://testing.fr/cubicweb/add/File?__linkto=attachment%%3A%s%%3Aobject&__redirectpath=ticket%%2F%s&__redirectvid='
                                 % (teid, teid)),
@@ -335,7 +334,7 @@ class TicketTC(TrackerBaseTC):
                                 'http://testing.fr/cubicweb/add/Card?__linkto=test_case_for%%3A%s%%3Asubject&__redirectpath=ticket%%2F%s&__redirectvid='
                                 % (teid, teid))])
         wf = self.t1.cw_adapt_to('IWorkflowable').current_workflow
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'start', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
                                 (self.t1.eid, wf.transition_by_name('start').eid)),
                                (u'reject', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
@@ -348,18 +347,18 @@ class TicketTC(TrackerBaseTC):
                                 (self.t1.eid, wf.transition_by_name('wait for feedback').eid)),
                                (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid)])
         movetonext = self.action_submenu(req, rset, 'movetonext')
-        self.assertEquals(len(movetonext), 1)
-        self.assertEquals(movetonext[0][0], '0.0.0')
+        self.assertEqual(len(movetonext), 1)
+        self.assertEqual(movetonext[0][0], '0.0.0')
         self.login('anon')
         req = self.request()
         rset = req.execute('Any X WHERE X is Ticket')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('addrelated', actions.AddRelatedActions),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [])
         self.restore_connection()
         req = self.request()
@@ -375,14 +374,14 @@ class TicketTC(TrackerBaseTC):
                               ('copy', actions.CopyAction),
                               ('actionsbox_notifications_mgmt', nosylist.INosyListManageNotificationsAction),
                               ('reply_comment', commentactions.AddCommentAction)])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [('add Ticket attachment File subject',
                                 'http://testing.fr/cubicweb/add/File?__linkto=attachment%%3A%s%%3Aobject&__redirectpath=ticket%%2F%s&__redirectvid='
                                 % (teid, teid)),
                                ('add Card test_case_for Ticket object',
                                 'http://testing.fr/cubicweb/add/Card?__linkto=test_case_for%%3A%s%%3Asubject&__redirectpath=ticket%%2F%s&__redirectvid='
                                 % (teid, teid))])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'ask validation', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
                                 (self.t1.eid, wf.transition_by_name('ask validation').eid)),
                                (u'reopen', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
@@ -392,19 +391,19 @@ class TicketTC(TrackerBaseTC):
         self.login('anon')
         req = self.request()
         rset = req.execute('Any X WHERE X is Ticket')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('addrelated', actions.AddRelatedActions),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
         self.restore_connection()
         self.t1.cw_adapt_to('IWorkflowable').fire_transition('ask validation')
         req = self.request()
         rset = req.execute('Any X WHERE X is Ticket')
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'resolve', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
                                 (self.t1.eid, wf.transition_by_name('resolve').eid)),
                                (u'reopen', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
@@ -424,25 +423,25 @@ class TicketTC(TrackerBaseTC):
                               ('copy', actions.CopyAction),
                               ('actionsbox_notifications_mgmt', nosylist.INosyListManageNotificationsAction),
                               ('reply_comment', commentactions.AddCommentAction)])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [('add Ticket attachment File subject',
                                 'http://testing.fr/cubicweb/add/File?__linkto=attachment%%3A%s%%3Aobject&__redirectpath=ticket%%2F%s&__redirectvid='
                                 % (teid, teid)),
                                ('add Card test_case_for Ticket object',
                                 'http://testing.fr/cubicweb/add/Card?__linkto=test_case_for%%3A%s%%3Asubject&__redirectpath=ticket%%2F%s&__redirectvid='
                                 % (teid, teid))])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
         self.login('anon')
         req = self.request()
         rset = req.execute('Any X WHERE X is Ticket')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('addrelated', actions.AddRelatedActions),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
 
     def test_state_change_on_version_publishing(self):
@@ -450,26 +449,26 @@ class TicketTC(TrackerBaseTC):
                           'WHERE P is Project').get_entity(0, 0)
         self.t1.set_relations(done_in=v2)
         self.commit()
-        t1iwf= self.t1.cw_adapt_to('IWorkflowable')
+        t1iwf = self.t1.cw_adapt_to('IWorkflowable')
         t1iwf.fire_transition('done')
         self.t1.clear_all_caches()
-        self.assertEquals(t1iwf.state, 'done')
+        self.assertEqual(t1iwf.state, 'done')
         self.commit()
         v2.clear_all_caches()
         v2._cw = self.request()
         v2iwf = v2.cw_adapt_to('IWorkflowable')
-        self.assertEquals(v2iwf.state, 'dev')
+        self.assertEqual(v2iwf.state, 'dev')
         v2.clear_all_caches()
         v2iwf.change_state('published')
         self.commit()
         self.t1.clear_all_caches()
-        self.assertEquals(t1iwf.state, 'validation pending')
-        # if the ticket is then moved to no version or to an unpublished version,
-        # reopen it.
+        self.assertEqual(t1iwf.state, 'validation pending')
+        # # if the ticket is then moved to no version or to an unpublished version,
+        # # reopen it.
         self.t1.set_relations(done_in=self.v)
         self.commit()
         self.t1.clear_all_caches()
-        self.assertEquals(t1iwf.state, 'open')
+        self.assertEqual(t1iwf.state, 'open')
 
     def test_version_publishing_cant_change_ticket_state(self):
         self.execute('INSERT CWGroup X: X name "cubicwebdevelopers"')
@@ -482,7 +481,7 @@ class TicketTC(TrackerBaseTC):
         t1iwf.fire_transition('done')
         self.t1.clear_all_caches()
         self.v.clear_all_caches()
-        self.assertEquals(t1iwf.state, 'done')
+        self.assertEqual(t1iwf.state, 'done')
         # -  Remove permission on the ticket for the clients
         self.execute('DELETE X require_permission P WHERE X eid %s' % self.t1.eid)
         self.commit()
@@ -494,7 +493,7 @@ class TicketTC(TrackerBaseTC):
         self.assertRaises(ValidationError, t1iwf.fire_transition, 'ask validation')
         v2.cw_adapt_to('IWorkflowable').fire_transition('publish')
         # - verify that ticket on which permissions were revoked remains in state
-        self.assertEquals(t1iwf.state, 'done')
+        self.assertEqual(t1iwf.state, 'done')
 
 
 class CommentTC(AutoPopulateTest):
@@ -520,7 +519,14 @@ class CommentTC(AutoPopulateTest):
 class FTITC(TrackerBaseTC):
     """Version"""
     config = ApptestConfiguration('data', sourcefile='sources_fti')
-    
+    @classmethod
+    def _build_repo(cls, *args, **kwargs):
+        try:
+            super(FTITC, cls)._build_repo(*args, **kwargs)
+        except Exception, ex:
+            # much probably on a wrong host
+            raise SkipTest(ex)
+
     def test_entity_weight(self):
         comment = self.request().create_entity('Comment',
                                                content=u'cubicweb comment')
@@ -529,7 +535,7 @@ class FTITC(TrackerBaseTC):
                                               reverse_comments=comment,
                                               concerns=self.cubicweb)
         self.commit()
-        self.assertEquals(self.request().execute('Any X ORDERBY FTIRANK(X) DESC WHERE X has_text "cubicweb"').rows,
+        self.assertEqual(self.request().execute('Any X ORDERBY FTIRANK(X) DESC WHERE X has_text "cubicweb"').rows,
                           [[self.cubicweb.eid], [ticket.eid], [comment.eid]])
 
 
