@@ -1,5 +1,4 @@
-"""functional tests for default forge security configuration
-"""
+"""functional tests for default forge security configuration"""
 from cubicweb import Binary, Unauthorized
 from cubicweb import devtools # necessary to import properly from cubes
 from cubes.tracker.testutils import create_ticket_rql
@@ -56,7 +55,7 @@ class ForgeSecurityTC(ForgeSecurityTC):
         cu.execute('INSERT File X: X data %(data)s, X data_name %(name)s, T attachment X WHERE T eid %(t)s',
                    {'data': Binary('hop'), 'name': u'hop.png', 't': ticket.eid})
         cnx.commit() # OK
-        self.assertEquals(len(ticket.attachment), 2)
+        self.assertEqual(len(ticket.attachment), 2)
 
     def test_ticket_developper_security(self):
         # cubicweb developer user submit ticket
@@ -72,7 +71,7 @@ class ForgeSecurityTC(ForgeSecurityTC):
     def test_ticket_workflow(self):
         b = self.create_ticket('a ticket').get_entity(0, 0)
         self.commit() # to set initial state properly
-        self.assertEquals(b.cw_adapt_to('IWorkflowable').state, 'open')
+        self.assertEqual(b.cw_adapt_to('IWorkflowable').state, 'open')
         # only project's developer or user in the staff group can pass the wait for feedback transition
         self._test_tr_fail('stduser', b.eid, 'wait for feedback')
         self._test_tr_fail('prj1client', b.eid, 'wait for feedback')
@@ -82,7 +81,7 @@ class ForgeSecurityTC(ForgeSecurityTC):
         self._test_tr_fail('stduser', b.eid, 'got feedback')
         self._test_tr_success('prj1client', b.eid, 'got feedback')
         #self._test_tr_success('staffuser', b.eid, 'got feedback')
-        self.assertEquals(b.cw_adapt_to('IWorkflowable').state, 'open')
+        self.assertEqual(b.cw_adapt_to('IWorkflowable').state, 'open')
         # only staff/developer can pass the start transition
         self._test_tr_fail('stduser', b.eid, 'start')
         self._test_tr_fail('prj1client', b.eid, 'start')
@@ -93,7 +92,7 @@ class ForgeSecurityTC(ForgeSecurityTC):
         self._test_tr_success('staffuser', b.eid, 'wait for feedback')
         self._test_tr_success('prj1developer', b.eid, 'got feedback')
         b.clear_all_caches()
-        self.assertEquals(b.cw_adapt_to('IWorkflowable').state, 'in-progress')
+        self.assertEqual(b.cw_adapt_to('IWorkflowable').state, 'in-progress')
         # staff/cubicweb developer can modify tickets even once no more in the open state
         cnx = self.mylogin('staffuser')
         cu = cnx.cursor()
