@@ -77,8 +77,8 @@ class ImageSideboxView(boxes.SideBoxView):
             # XXX huumm
             gallery_url = '%s/documentation' % entity.project.absolute_url()
         else:
-            gallery_url = u'%s%s' % (self.build_url(vid='gallery',
-                                                    rql=self.cw_rset.printable_rql()),
+            gallery_url = u'%s%s' % (self._cw.build_url(vid='gallery',
+                                                        rql=self.cw_rset.printable_rql()),
                                      '&selected=%s' % entity.eid)
         if len(self.cw_rset) > 1:
             see_all_url = u'[<a href="%s">%s (%s)</a>]' % (xml_escape(gallery_url),
