@@ -7,7 +7,7 @@
 __docformat__ = "restructuredtext en"
 _ = unicode
 
-from cubicweb.selectors import implements
+from cubicweb.selectors import is_instance
 from cubicweb.web import uicfg, component
 
 from cubes.tracker.views import version as tracker
@@ -18,7 +18,7 @@ for attr in ('progress_target', 'progress_done', 'progress_todo'):
 
 class VersionBurndownChartVComponent(component.EntityVComponent):
     __regid__ = 'versionburndown'
-    __select__ = component.EntityVComponent.__select__ & implements('Version')
+    __select__ = component.EntityVComponent.__select__ & is_instance('Version')
     rql = ('Any X,CD,L,LL where X load L, X load_left LL, '
            'X creation_date CD, X done_in V, V eid %s')
 
@@ -35,7 +35,7 @@ class VersionBurndownChartVComponent(component.EntityVComponent):
             'Any T GROUPBY T  WHERE T done_in V, V eid %%(v)s, '
             'T in_state S, NOT S name IN (%s), TR wf_info_for T '
             'HAVING COUNT(TR)=0' % ','.join('"%s"' % st for st in ticketcls.OPEN_STATES),
-           {'v': version.eid}, 'v')
+           {'v': version.eid})
         if rset:
             self.w(u'<div class="needsvalidation">%s</div>'
                    % self._cw._("Some tickets don't have a regular workflow, "
@@ -48,7 +48,7 @@ class VersionBurndownChartVComponent(component.EntityVComponent):
 class VersionTestCardBarVComponent(component.RelatedObjectsVComponent):
     """display version's test instances of test card"""
     __regid__ = 'versiontests'
-    __select__ = component.RelatedObjectsVComponent.__select__ & implements('Version')
+    __select__ = component.RelatedObjectsVComponent.__select__ & is_instance('Version')
 
     rtype = 'for_version'
     target = 'subject'
